AdRequestError class

单次广告请求失败的详细信息。

Constructors

AdRequestError({required String operation, required int code, required String message})
const

Properties

code int
原生 SDK 返回的错误码;未知错误为 -1。
final
hashCode int
The hash code for this object.
no setterinherited
message String
原生 SDK 返回的错误信息。
final
operation String
发生失败的插件方法,例如 initAdshowSplashAd
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited